(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     64541,       2235]*)
(*NotebookOutlinePosition[     65436,       2265]*)
(*  CellTagsIndexPosition[     65392,       2261]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Intro.nb", "Title",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  TextAlignment->Center],

Cell["Wilfrid S. Kendall", "Subtitle",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  TextAlignment->Center],

Cell[TextData[
"Statistics, University of Warwick, \nCoventry CV4 7AL, UK."], "Subsubtitle",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  TextAlignment->Center],

Cell[CellGroupData[{

Cell["Contact information:", "SmallText",
  Editable->False,
  Evaluatable->False,
  FontFamily->"Times New Roman",
  FontSize->10,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontColor->RGBColor[0.501961, 0, 0],
  Background->GrayLevel[1],
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[TextData["Email: w.s.kendall@warwick.ac.uk"], "Name",
  Editable->False,
  Evaluatable->False,
  CellHorizontalScrolling->False,
  FontFamily->"Times New Roman",
  FontSize->10,
  FontSlant->"Italic",
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell["URL: http://www.warwick.ac.uk/go/WSK", "Name",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  FontFamily->"Times New Roman",
  FontSize->10,
  FontSlant->"Italic",
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Acknowledgements:"], "SmallText",
  Editable->False,
  Evaluatable->False,
  FontFamily->"Times New Roman",
  FontSize->10,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontColor->RGBColor[0.501961, 0, 0],
  Background->GrayLevel[1],
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[TextData[
"The research reported here was supported by EPSRC grants GR/71677 \
(Stochastic calculus in AXIOM using modules of stochastic differentials) and \
GR/L56831 (Perfect simulation in stochastic geometry), and a joint \
EPSRC/BBSRC research grant (Multi-strain species modelling and control via \
differential algebra reductions). This Mathematica notebook was prepared \
during a visit to MSRI Berkeley during its 1997-1998 program Stochastic \
Analysis. Finally it is a pleasure to express my gratitude to my friends \
Suzanne Scotchmer and Joseph Farrell for the generous hospitality they showed \
to me during my visit to MSRI."], "SmallText",
  Editable->False,
  Evaluatable->False,
  FontFamily->"Times New Roman",
  FontSize->10,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1],
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}]
}, Closed]],

Cell["\<\
Purpose: this is a Mathematica package (working under Mathematica 5.1.1) \
which introduces Itovsn3. At various points hidden cells (flagged as WARNING) \
carry information about points where  Itovsn3  assumes the user has taken \
appropriate precautions to ensure input is compatible with stochastic \
calculus theory: expect nonsensical output where these assumptions are \
violated! After a number of simple preliminary sections demonstrating the \
basic features, the final section gives an extended treatment sketching a \
Mathematica implementation of an easy algorithm to evaluate a class of Ito \
integrals. \
\>", "SmallText",
  Evaluatable->False,
  FontFamily->"Times New Roman",
  FontSize->10,
  FontSlant->"Italic",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell[CellGroupData[{

Cell[TextData["References:"], "SmallText",
  Evaluatable->False,
  FontFamily->"Times New Roman",
  FontSize->10,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1],
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[CellGroupData[{

Cell[TextData[
"Discussion of this and other implementations of symbolic Ito calculus in \
REDUCE and AXIOM (all going under the generic title of Itovsn3):"], 
  "SmallText",
  Evaluatable->False,
  FontFamily->"Times New Roman",
  FontSize->10,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1],
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[TextData[
"WSK: \"Computer algebra in Probability and Statistics\", Statistica \
Neerlandica, 47:9-25 (1993)."], "SmallText",
  Evaluatable->False,
  FontFamily->"Times New Roman",
  FontSize->10,
  FontSlant->"Italic",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell[TextData[
"WSK: \"Symbolic Ito calculus: an ongoing story\", Research Report 327, \
Department of Statistics, University of Warwick, submitted for publication \
(1998)."], "SmallText",
  Evaluatable->False,
  FontFamily->"Times New Roman",
  FontSize->10,
  FontSlant->"Italic",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Symbolic Ito calculus in REDUCE:"], "SmallText",
  Evaluatable->False,
  FontFamily->"Times New Roman",
  FontSize->10,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1],
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[TextData[
"WSK: \"Symbolic Ito calculus: An overview\", in Probabilites Numeriques, \
edited by N. Bouleau and D. Talay, INRIA, Rocquencourt, pp 186-192 (1991)."], 
  "SmallText",
  Evaluatable->False,
  FontFamily->"Times New Roman",
  FontSize->10,
  FontSlant->"Italic",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Symbolic Ito calculus in Mathematica:"], "SmallText",
  Evaluatable->False,
  FontFamily->"Times New Roman",
  FontSize->10,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1],
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[TextData[
"WSK: \"Doing stochastic calculus with Mathematica\", in Economic and \
Financial Modeling with Mathematica, edited by H. Varian, Springer-Verlag, \
New York, pp 214-238 (1993)."], "SmallText",
  Evaluatable->False,
  FontFamily->"Times New Roman",
  FontSize->10,
  FontSlant->"Italic",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Symbolic Ito calculus in AXIOM:"], "SmallText",
  Evaluatable->False,
  FontFamily->"Times New Roman",
  FontSize->10,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1],
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[TextData[
"WSK: \"Itovsn3 in AXIOM: modules, algebras and  stochastic differentials\", \
Research Report 328, Department of Statistics, University of Warwick \
(1998)."], "SmallText",
  Evaluatable->False,
  FontFamily->"Times New Roman",
  FontSize->10,
  FontSlant->"Italic",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[
"This notebook assumes no previous definitions in the Mathematica workspace. \
If this is not the case, then quit Mathematica and restart.\n\nFirst we \
ensure that the Itovsn3 package is loaded. For this to work properly, it is \
necessary that the file  Itovsn3.m  be present in a location looked at by \
Mathematica as part of Mathematica's response to the  Needs  statement \
below."], "Text",
  Evaluatable->False],

Cell[BoxData[
    \(\(Needs["\<Itovsn3`\>"];\)\)], "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]]
}, Closed]],

Cell[BoxData[
    \(Needs["\<Itovsn3`\>"]\)], "Input"],

Cell[CellGroupData[{

Cell["Initialize Itovsn3", "Section",
  Evaluatable->False],

Cell[TextData[
"Various private structures have to be set up within the  Itovsn3  package. \
The following command does this work, and nominates  t  as the basic \
semimartingale measuring time, and dt  as its stochastic differential. (Note: \
there is a related command  ItoInit[t,dt]  which does essentially the same \
work but does not clear the semimartingales and stochastic differentials \
relating to private structures:  ItoReset[t,dt]  is therefore preferable if \
there is any chance of previous  Itovsn3  sessions having already created \
these structures.)"], "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[
    \(ItoReset[t, dt]\)], "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {"\<\"Itovsn3  resetting ...\"\>"},
          {"\<\"Itovsn3  initialized\"\>"},
          {
            
            InterpretationBox[\("with time semimartingale "\[InvisibleSpace]t\
\),
              SequenceForm[ "with time semimartingale ", t],
              Editable->False]},
          {
            
            InterpretationBox[\("and time differential "\[InvisibleSpace]dt\),
              
              SequenceForm[ "and time differential ", dt],
              Editable->False]}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {"Itovsn3  resetting ...", "Itovsn3  initialized", 
        SequenceForm[ "with time semimartingale ", t], 
        SequenceForm[ "and time differential ", dt]}]]], "Output"]
}, Open  ]],

Cell[TextData[
"Inspect the resulting second-order structure. Before anything is done this \
structure is very simple, carrying information only about  t  and its \
associated stochastic differential  dt.  Note that  dt  is a conventional \
differential, so  dt^2 == 0  in the multiplication table, and  Drift[dt] == \
dt  in the drift table."], "Text",
  Evaluatable->False,
  FontFamily->"Times New Roman",
  FontSize->12,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1],
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[CellGroupData[{

Cell[BoxData[
    \(ItoStatus[]\)], "Input",
  PageWidth->Infinity],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {"\<\"---------------\"\>"},
          {"\<\"Summary of current structure of stochastic \
differentials\"\>"},
          {"\<\"- - - - - - - -\"\>"},
          {"\<\"Current second-order structure of semimartingale \
differentials:\"\>"},
          {
            TagBox[GridBox[{
                  {"\<\"\"\>", "dt"},
                  {"0", ""}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              Function[ BoxForm`e$, 
                TableForm[ BoxForm`e$, TableHeadings -> {{dt}, {dt}}]]]},
          {"\<\"- - - - - - - -\"\>"},
          {"\<\"Current first-order structure of semimartingale \
differentials:\"\>"},
          {
            InterpretationBox[GridBox[{
                  {"dt"}
                  },
                RowSpacings->3,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              
              TableForm[ {dt}, TableDirections -> Row, TableHeadings -> {{
                dt}, {"Drifts:"}}]]},
          {"\<\"- - - - - - - -\"\>"},
          {"\<\"Current initial values:\"\>"},
          {
            InterpretationBox[GridBox[{
                  {"0"}
                  },
                RowSpacings->3,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              
              TableForm[ {0}, TableDirections -> Row, TableHeadings -> {{t}, {
                "Initially:"}}]]},
          {"\<\"---------------\"\>"}
          },
        GridBaseline->{Baseline, {1, 1}},
        ColumnAlignments->{Left}],
      ColumnForm[ {"---------------", 
        "Summary of current structure of stochastic differentials", 
        "- - - - - - - -", 
        "Current second-order structure of semimartingale differentials:", 
        TableForm[ {{0}}, TableHeadings -> {{dt}, {dt}}], "- - - - - - - -", 
        "Current first-order structure of semimartingale differentials:", 
        TableForm[ {dt}, TableDirections -> Row, TableHeadings -> {{dt}, {
          "Drifts:"}}], "- - - - - - - -", "Current initial values:", 
        TableForm[ {0}, TableDirections -> Row, TableHeadings -> {{t}, {
          "Initially:"}}], "---------------"}],
      Editable->False]], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Introducing a general semimartingale", "Section",
  Evaluatable->False],

Cell[TextData[
"First introduce a semimartingale  X  and its stochastic differential  dX:"], 
  "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[
    \(Introduce[X, dX]\)], "Input",
  PageWidth->Infinity],

Cell[BoxData[
    \({dX, dt}\)], "Output"]
}, Open  ]],

Cell[TextData[
"Examine the second-order structure: note the use of placeholders  (dt \
Brktbydt[dX, dX],  dt Drftbydt[dX], (Fixed[0, X])  where structure has not \
yet been defined!"], "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[
    \(ItoStatus[]\)], "Input",
  PageWidth->Infinity],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {"\<\"---------------\"\>"},
          {"\<\"Summary of current structure of stochastic \
differentials\"\>"},
          {"\<\"- - - - - - - -\"\>"},
          {"\<\"Current second-order structure of semimartingale \
differentials:\"\>"},
          {
            TagBox[GridBox[{
                  {"\<\"\"\>", "dX", "dt"},
                  {"dX", \(dt\ Brktbydt[dX, dX]\), "0"},
                  {"dt", "0", "0"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              Function[ BoxForm`e$, 
                TableForm[ 
                BoxForm`e$, TableHeadings -> {{dX, dt}, {dX, dt}}]]]},
          {"\<\"- - - - - - - -\"\>"},
          {"\<\"Current first-order structure of semimartingale \
differentials:\"\>"},
          {
            InterpretationBox[GridBox[{
                  {"dX", "dt"},
                  {\(dt\ Drftbydt[dX]\), "dt"}
                  },
                RowSpacings->3,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              TableForm[ {
                Times[ dt, 
                  Drftbydt[ dX]], dt}, TableDirections -> Row, 
                TableHeadings -> {{dX, dt}, {"Drifts:"}}]]},
          {"\<\"- - - - - - - -\"\>"},
          {"\<\"Current initial values:\"\>"},
          {
            InterpretationBox[GridBox[{
                  {"X", "t"},
                  {\(Fixed[0, X]\), "0"}
                  },
                RowSpacings->3,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              TableForm[ {
                Fixed[ 0, X], 0}, TableDirections -> Row, TableHeadings -> {{
                X, t}, {"Initially:"}}]]},
          {"\<\"---------------\"\>"}
          },
        GridBaseline->{Baseline, {1, 1}},
        ColumnAlignments->{Left}],
      ColumnForm[ {"---------------", 
        "Summary of current structure of stochastic differentials", 
        "- - - - - - - -", 
        "Current second-order structure of semimartingale differentials:", 
        TableForm[ {{
          Times[ dt, 
            Brktbydt[ dX, dX]], 0}, {0, 0}}, TableHeadings -> {{dX, dt}, {dX, 
          dt}}], "- - - - - - - -", 
        "Current first-order structure of semimartingale differentials:", 
        TableForm[ {
          Times[ dt, 
            Drftbydt[ dX]], dt}, TableDirections -> Row, TableHeadings -> {{
          dX, dt}, {"Drifts:"}}], "- - - - - - - -", 
        "Current initial values:", 
        TableForm[ {
          Fixed[ 0, X], 0}, TableDirections -> Row, TableHeadings -> {{X, 
          t}, {"Initially:"}}], "---------------"}],
      Editable->False]], "Print"]
}, Open  ]],

Cell[TextData["The stochastic differential is found using  ItoD. "], "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[
    \(ItoD[X]\)], "Input",
  PageWidth->Infinity],

Cell[BoxData[
    \(dX\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(sd = ItoD[X\^2]\)], "Input",
  PageWidth->Infinity],

Cell[BoxData[
    \(2\ dX\ X + dt\ Brktbydt[dX, dX]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Warning", "Subsection",
  Evaluatable->False,
  FontFamily->"Times New Roman",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0],
  Background->None],

Cell["\<\
ItoD[sd]  does not check that  sd  is of the correct form. If  sd  is not a \
stochastic  differential then output will be nonsensical!\
\>", "Text",
  Evaluatable->False,
  FontColor->RGBColor[1, 0, 0],
  Background->None]
}, Closed]],

Cell[TextData["Drifts are found by using  Drift:"], "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[
    \(sd1 = Drift[sd]\)], "Input",
  PageWidth->Infinity],

Cell[BoxData[
    \(dt\ Brktbydt[dX, dX] + 2\ dt\ X\ Drftbydt[dX]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Warning", "Subsection",
  Evaluatable->False,
  FontFamily->"Times New Roman",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0],
  Background->GrayLevel[1]],

Cell["\<\
Drift[sd]  does not check that  sd  is of the correct form.  If  sd  is not a \
stochastic differential then output will be nonsensical.\
\>", "Text",
  Evaluatable->False,
  FontColor->RGBColor[1, 0, 0]]
}, Closed]],

Cell[TextData["Initial values are found by using  Initialvalue"], "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[
    \(X0 = InitialValue[0, X]\)], "Input",
  PageWidth->Infinity],

Cell[BoxData[
    \(Fixed[0, X]\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Specifying the semimartingale to be one-dimensional Brownian motion\
\>", "Section",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[TextData[
"We need to set various parts of the second-order structure.\nFirst of all, \
the quadratic variation:"], "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[
    \(AddQuadVar[dX\^2, dt]\)], "Input",
  PageWidth->Infinity],

Cell[BoxData[
    \(1\)], "Output"]
}, Open  ]],

Cell[TextData[
"The effect is seen immediately when we examine  sd  and  sd1:"], "Text",
  Evaluatable->False,
  FontFamily->"Times New Roman",
  FontSize->12,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1],
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[CellGroupData[{

Cell[BoxData[
    \(sd\)], "Input",
  PageWidth->Infinity],

Cell[BoxData[
    \(dt + 2\ dX\ X\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(sd1\)], "Input",
  PageWidth->Infinity],

Cell[BoxData[
    \(dt + 2\ dt\ X\ Drftbydt[dX]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Warning", "Subsection",
  Evaluatable->False,
  FontColor->RGBColor[1, 0, 0]],

Cell["\<\
It should be noted that  Itovsn3  does not check to ensure that the quadratic \
variation term is non-negative or even a stochastic differential: this is the \
user's responsibility. The result of  AddQuadVar[dX^2,-dt]  would typically \
be nonsensical. (The reason for not checking? if the  dt  or  -dt  term was \
replaced by a large symbolic expression then checking for non-negativity \
would be a substantial piece of work!) Furthermore  Itovsn3  does not check \
to ensure that the quadratic variation term is a classical differential (zero \
quadratic variation and zero quadratic co-variation with other stochastic \
differentials, and left unchanged by application  of  Drift).\
\>", "Text",
  Evaluatable->False,
  FontColor->RGBColor[1, 0, 0]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Then, the drift:"], "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[
    \(AddDrift[dX, 0]\)], "Input",
  PageWidth->Infinity],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[TextData["The effect is seen immediately when we examine  sd1"], "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[
    \(sd1\)], "Input",
  PageWidth->Infinity],

Cell[BoxData[
    \(dt\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Warning", "Subsection",
  Evaluatable->False,
  FontColor->RGBColor[1, 0, 0]],

Cell["\<\
Note that  Itovsn3  does not check the suitability of the drift term. It \
should be a classical stochastic differential: zero quadratic variation (in \
fact it should also be the case that it has zero quadratic co-variation with \
all other semimartingales, or else non-negative definiteness fails!) and left \
unchanged by a further application of  Drift.\
\>", "Text",
  Evaluatable->False,
  FontColor->RGBColor[1, 0, 0]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"More generally we have to use  ItoExpand  (in accordance with Mathematica's \
general philosophy, and in contrast to other implementations of  Itovsn3,  \
here we do not expand stochastic differentials by default):"], "Text",
  Evaluatable->False,
  FontFamily->"Times New Roman",
  FontSize->12,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1],
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[CellGroupData[{

Cell[BoxData[
    \(dX\^2\)], "Input",
  PageWidth->Infinity],

Cell[BoxData[
    \(dX\^2\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ItoExpand[dX\^2]\)], "Input",
  PageWidth->Infinity],

Cell[BoxData[
    \(dt\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Finally we can also change the initial value: this is occasionally useful \
(see for example its use in the notebook  Itoarea):"], "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[
    \(AddFixed[0, X, 1]\)], "Input",
  PageWidth->Infinity],

Cell[BoxData[
    \(1\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(InitialValue[0, a\ X\^2]\)], "Input",
  PageWidth->Infinity],

Cell[BoxData[
    \(a\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Warning", "Subsection",
  Evaluatable->False,
  FontFamily->"Times New Roman",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0],
  Background->GrayLevel[1]],

Cell["\<\
Again  Itovsn3  does not check the validity of each of the arguments.\
\>", "Text",
  Evaluatable->False,
  FontColor->RGBColor[1, 0, 0]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"The total effect can be seen by examining the structure using  ItoStatus: "],
   "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[
    \(ItoStatus[]\)], "Input",
  PageWidth->Infinity],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {"\<\"---------------\"\>"},
          {"\<\"Summary of current structure of stochastic \
differentials\"\>"},
          {"\<\"- - - - - - - -\"\>"},
          {"\<\"Current second-order structure of semimartingale \
differentials:\"\>"},
          {
            TagBox[GridBox[{
                  {"\<\"\"\>", "dX", "dt"},
                  {"dX", "dt", "0"},
                  {"dt", "0", "0"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              Function[ BoxForm`e$, 
                TableForm[ 
                BoxForm`e$, TableHeadings -> {{dX, dt}, {dX, dt}}]]]},
          {"\<\"- - - - - - - -\"\>"},
          {"\<\"Current first-order structure of semimartingale \
differentials:\"\>"},
          {
            InterpretationBox[GridBox[{
                  {"dX", "dt"},
                  {"0", "dt"}
                  },
                RowSpacings->3,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              
              TableForm[ {0, dt}, TableDirections -> Row, TableHeadings -> {{
                dX, dt}, {"Drifts:"}}]]},
          {"\<\"- - - - - - - -\"\>"},
          {"\<\"Current initial values:\"\>"},
          {
            InterpretationBox[GridBox[{
                  {"X", "t"},
                  {"1", "0"}
                  },
                RowSpacings->3,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              
              TableForm[ {1, 0}, TableDirections -> Row, TableHeadings -> {{X,
                 t}, {"Initially:"}}]]},
          {"\<\"---------------\"\>"}
          },
        GridBaseline->{Baseline, {1, 1}},
        ColumnAlignments->{Left}],
      ColumnForm[ {"---------------", 
        "Summary of current structure of stochastic differentials", 
        "- - - - - - - -", 
        "Current second-order structure of semimartingale differentials:", 
        TableForm[ {{dt, 0}, {0, 0}}, TableHeadings -> {{dX, dt}, {dX, dt}}], 
        "- - - - - - - -", 
        "Current first-order structure of semimartingale differentials:", 
        TableForm[ {0, dt}, TableDirections -> Row, TableHeadings -> {{dX, 
          dt}, {"Drifts:"}}], "- - - - - - - -", "Current initial values:", 
        TableForm[ {1, 0}, TableDirections -> Row, TableHeadings -> {{X, t}, {
          "Initially:"}}], "---------------"}],
      Editable->False]], "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Adding another semimartingale as independent one-dimensional Brownian \
motion"], "Section",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[TextData["We introduce a further semimartingale:"], "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[
    \(Introduce[Y, dY]\)], "Input",
  PageWidth->Infinity],

Cell[BoxData[
    \({dY, dX, dt}\)], "Output"]
}, Open  ]],

Cell[TextData["We specify this as another standard Brownian motion:"], "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[{
    \(AddQuadVar[dY\^2, dt]\), "\n", 
    \(AddDrift[dY, 0]\), "\n", 
    \(AddFixed[0, Y, 0]\)}], "Input",
  PageWidth->Infinity],

Cell[BoxData[
    \(1\)], "Output"],

Cell[BoxData[
    \(0\)], "Output"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[
"Examining the second-order structure, we see that we should also specify the \
quadratic co-variation!"], "Text",
  Evaluatable->False,
  FontFamily->"Times New Roman",
  FontSize->12,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1],
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[CellGroupData[{

Cell[BoxData[
    \(ItoStatus[]\)], "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {"\<\"---------------\"\>"},
          {"\<\"Summary of current structure of stochastic \
differentials\"\>"},
          {"\<\"- - - - - - - -\"\>"},
          {"\<\"Current second-order structure of semimartingale \
differentials:\"\>"},
          {
            TagBox[GridBox[{
                  {"\<\"\"\>", "dY", "dX", "dt"},
                  {"dY", "dt", \(dt\ Brktbydt[dX, dY]\), "0"},
                  {"dX", \(dt\ Brktbydt[dX, dY]\), "dt", "0"},
                  {"dt", "0", "0", "0"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              Function[ BoxForm`e$, 
                TableForm[ 
                BoxForm`e$, TableHeadings -> {{dY, dX, dt}, {dY, dX, 
                  dt}}]]]},
          {"\<\"- - - - - - - -\"\>"},
          {"\<\"Current first-order structure of semimartingale \
differentials:\"\>"},
          {
            InterpretationBox[GridBox[{
                  {"dY", "dX", "dt"},
                  {"0", "0", "dt"}
                  },
                RowSpacings->3,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              
              TableForm[ {0, 0, dt}, TableDirections -> Row, 
                TableHeadings -> {{dY, dX, dt}, {"Drifts:"}}]]},
          {"\<\"- - - - - - - -\"\>"},
          {"\<\"Current initial values:\"\>"},
          {
            InterpretationBox[GridBox[{
                  {"Y", "X", "t"},
                  {"0", "1", "0"}
                  },
                RowSpacings->3,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              
              TableForm[ {0, 1, 0}, TableDirections -> Row, 
                TableHeadings -> {{Y, X, t}, {"Initially:"}}]]},
          {"\<\"---------------\"\>"}
          },
        GridBaseline->{Baseline, {1, 1}},
        ColumnAlignments->{Left}],
      ColumnForm[ {"---------------", 
        "Summary of current structure of stochastic differentials", 
        "- - - - - - - -", 
        "Current second-order structure of semimartingale differentials:", 
        TableForm[ {{dt, 
          Times[ dt, 
            Brktbydt[ dX, dY]], 0}, {
          Times[ dt, 
            Brktbydt[ dX, dY]], dt, 0}, {0, 0, 0}}, TableHeadings -> {{dY, dX,
           dt}, {dY, dX, dt}}], "- - - - - - - -", 
        "Current first-order structure of semimartingale differentials:", 
        TableForm[ {0, 0, dt}, TableDirections -> Row, TableHeadings -> {{dY, 
          dX, dt}, {"Drifts:"}}], "- - - - - - - -", 
        "Current initial values:", 
        TableForm[ {0, 1, 0}, TableDirections -> Row, TableHeadings -> {{Y, X,
           t}, {"Initially:"}}], "---------------"}],
      Editable->False]], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["There are three equivalent ways to do this:"], "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[{
    \(AddQuadVar[dX, dY, 0]; ItoExpand[dX\ dY]\), "\n", 
    \(AddQuadVar[dY, dX, 0]; ItoExpand[dX\ dY]\), "\n", 
    \(AddQuadVar[dX\ dY, 0]; ItoExpand[dX\ dY]\)}], "Input",
  PageWidth->Infinity],

Cell[BoxData[
    \(0\)], "Output"],

Cell[BoxData[
    \(0\)], "Output"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Warning", "Subsection",
  Evaluatable->False,
  FontColor->RGBColor[1, 0, 0]],

Cell["\<\
It should be noted that  Itovsn3  makes no check as to whether the total \
matrix of quadratic covariations is non-negative definite (required if \
stochastic analysis is to make sense!). It is the user's responsibility to \
ensure that this is so! For example, if we had required  \
AddQuadVar[dX*dY,4*dt]  then non-negative definiteness would have failed, and \
the output of  Itovsn3  in answer to subsequent questions would typically be \
nonsensical.\
\>", "Text",
  Evaluatable->False,
  FontColor->RGBColor[1, 0, 0]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ItoStatus[]\)], "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {"\<\"---------------\"\>"},
          {"\<\"Summary of current structure of stochastic \
differentials\"\>"},
          {"\<\"- - - - - - - -\"\>"},
          {"\<\"Current second-order structure of semimartingale \
differentials:\"\>"},
          {
            TagBox[GridBox[{
                  {"\<\"\"\>", "dY", "dX", "dt"},
                  {"dY", "dt", "0", "0"},
                  {"dX", "0", "dt", "0"},
                  {"dt", "0", "0", "0"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              Function[ BoxForm`e$, 
                TableForm[ 
                BoxForm`e$, TableHeadings -> {{dY, dX, dt}, {dY, dX, 
                  dt}}]]]},
          {"\<\"- - - - - - - -\"\>"},
          {"\<\"Current first-order structure of semimartingale \
differentials:\"\>"},
          {
            InterpretationBox[GridBox[{
                  {"dY", "dX", "dt"},
                  {"0", "0", "dt"}
                  },
                RowSpacings->3,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              
              TableForm[ {0, 0, dt}, TableDirections -> Row, 
                TableHeadings -> {{dY, dX, dt}, {"Drifts:"}}]]},
          {"\<\"- - - - - - - -\"\>"},
          {"\<\"Current initial values:\"\>"},
          {
            InterpretationBox[GridBox[{
                  {"Y", "X", "t"},
                  {"0", "1", "0"}
                  },
                RowSpacings->3,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              
              TableForm[ {0, 1, 0}, TableDirections -> Row, 
                TableHeadings -> {{Y, X, t}, {"Initially:"}}]]},
          {"\<\"---------------\"\>"}
          },
        GridBaseline->{Baseline, {1, 1}},
        ColumnAlignments->{Left}],
      ColumnForm[ {"---------------", 
        "Summary of current structure of stochastic differentials", 
        "- - - - - - - -", 
        "Current second-order structure of semimartingale differentials:", 
        TableForm[ {{dt, 0, 0}, {0, dt, 0}, {0, 0, 0}}, TableHeadings -> {{dY,
           dX, dt}, {dY, dX, dt}}], "- - - - - - - -", 
        "Current first-order structure of semimartingale differentials:", 
        TableForm[ {0, 0, dt}, TableDirections -> Row, TableHeadings -> {{dY, 
          dX, dt}, {"Drifts:"}}], "- - - - - - - -", 
        "Current initial values:", 
        TableForm[ {0, 1, 0}, TableDirections -> Row, TableHeadings -> {{Y, X,
           t}, {"Initially:"}}], "---------------"}],
      Editable->False]], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"This allows us to compute more sophisticated stochastic differentials"], 
  "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[
    \(ItoD[X\/\(Y + 1\)]\)], "Input",
  PageWidth->Infinity],

Cell[BoxData[
    \(\(dt\ X\)\/\((1 + Y)\)\^3 - \(dY\ X\)\/\((1 + Y)\)\^2 + 
      dX\/\(1 + Y\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Warning", "Subsection",
  Evaluatable->False,
  FontFamily->"Times New Roman",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0],
  Background->GrayLevel[1]],

Cell["\<\
Notice that  Itovsn3  does NOT track the possibility of divergence of terms. \
It provides a local, formal, algebraic analysis: it is the user's \
responsibility to ensure that the input makes sense in terms of stochastic \
calculus, and to determine the conditions under which the output is correct \
(here, random intervals of time where  1+Y  does not vanish!).\
\>", "Text",
  Evaluatable->False,
  FontColor->RGBColor[1, 0, 0]]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"A quicker way to introduce multidimensional Brownian motions"], "Section",
  Evaluatable->False],

Cell[TextData[
"The above is long-winded. Here is a quicker method! First we clear the old \
structure."], "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[
    \(ItoReset[t, dt]\)], "Input",
  PageWidth->Infinity],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {"\<\"Itovsn3  resetting ...\"\>"},
          {"\<\"Itovsn3  initialized\"\>"},
          {
            
            InterpretationBox[\("with time semimartingale "\[InvisibleSpace]t\
\),
              SequenceForm[ "with time semimartingale ", t],
              Editable->False]},
          {
            
            InterpretationBox[\("and time differential "\[InvisibleSpace]dt\),
              
              SequenceForm[ "and time differential ", dt],
              Editable->False]}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {"Itovsn3  resetting ...", "Itovsn3  initialized", 
        SequenceForm[ "with time semimartingale ", t], 
        SequenceForm[ "and time differential ", dt]}]]], "Output"]
}, Open  ]],

Cell[TextData[
"Now we introduce the processes just as before, but with a single command.\n\
The reader can see for themselves that the result is the same!"], "Text",
  Evaluatable->False,
  FontFamily->"Times New Roman",
  FontSize->12,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1],
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(BrownBasis[{X, Y}, {1, 0}];\)\), "\n", 
    \(ItoStatus[]\)}], "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {"\<\"---------------\"\>"},
          {"\<\"Summary of current structure of stochastic \
differentials\"\>"},
          {"\<\"- - - - - - - -\"\>"},
          {"\<\"Current second-order structure of semimartingale \
differentials:\"\>"},
          {
            TagBox[GridBox[{
                  {"\<\"\"\>", "dY", "dX", "dt"},
                  {"dY", "dt", "0", "0"},
                  {"dX", "0", "dt", "0"},
                  {"dt", "0", "0", "0"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              Function[ BoxForm`e$, 
                TableForm[ 
                BoxForm`e$, TableHeadings -> {{dY, dX, dt}, {dY, dX, 
                  dt}}]]]},
          {"\<\"- - - - - - - -\"\>"},
          {"\<\"Current first-order structure of semimartingale \
differentials:\"\>"},
          {
            InterpretationBox[GridBox[{
                  {"dY", "dX", "dt"},
                  {"0", "0", "dt"}
                  },
                RowSpacings->3,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              
              TableForm[ {0, 0, dt}, TableDirections -> Row, 
                TableHeadings -> {{dY, dX, dt}, {"Drifts:"}}]]},
          {"\<\"- - - - - - - -\"\>"},
          {"\<\"Current initial values:\"\>"},
          {
            InterpretationBox[GridBox[{
                  {"Y", "X", "t"},
                  {"0", "1", "0"}
                  },
                RowSpacings->3,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              
              TableForm[ {0, 1, 0}, TableDirections -> Row, 
                TableHeadings -> {{Y, X, t}, {"Initially:"}}]]},
          {"\<\"---------------\"\>"}
          },
        GridBaseline->{Baseline, {1, 1}},
        ColumnAlignments->{Left}],
      ColumnForm[ {"---------------", 
        "Summary of current structure of stochastic differentials", 
        "- - - - - - - -", 
        "Current second-order structure of semimartingale differentials:", 
        TableForm[ {{dt, 0, 0}, {0, dt, 0}, {0, 0, 0}}, TableHeadings -> {{dY,
           dX, dt}, {dY, dX, dt}}], "- - - - - - - -", 
        "Current first-order structure of semimartingale differentials:", 
        TableForm[ {0, 0, dt}, TableDirections -> Row, TableHeadings -> {{dY, 
          dX, dt}, {"Drifts:"}}], "- - - - - - - -", 
        "Current initial values:", 
        TableForm[ {0, 1, 0}, TableDirections -> Row, TableHeadings -> {{Y, X,
           t}, {"Initially:"}}], "---------------"}],
      Editable->False]], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Working with stochastic differential equations "], "Section",
  Evaluatable->False],

Cell[TextData[
"Specification of semimartingales can be done very concisely using stochastic \
differentials equations. Here is a specification of the Levy stochastic area \
(see also the  Itoarea  notebook), based on the two-dimensional Brownian \
motion  {X,Y}:"], "Text",
  Evaluatable->False],

Cell[BoxData[
    \(Itosde[Z, dZ == Y\ dX - X\ dY, Z0]\)], "Input",
  PageWidth->Infinity],

Cell[TextData["The result is as required:"], "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[
    \(ItoStatus[]\)], "Input",
  PageWidth->Infinity],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {"\<\"---------------\"\>"},
          {"\<\"Summary of current structure of stochastic \
differentials\"\>"},
          {"\<\"- - - - - - - -\"\>"},
          {"\<\"Current second-order structure of semimartingale \
differentials:\"\>"},
          {
            TagBox[GridBox[{
                  {"\<\"\"\>", "dZ", "dY", "dX", "dt"},
                  {"dZ", \(dt\ X\^2 + dt\ Y\^2\), \(\(-dt\)\ X\), \(dt\ Y\), 
                    "0"},
                  {"dY", \(\(-dt\)\ X\), "dt", "0", "0"},
                  {"dX", \(dt\ Y\), "0", "dt", "0"},
                  {"dt", "0", "0", "0", "0"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              Function[ BoxForm`e$, 
                TableForm[ 
                BoxForm`e$, TableHeadings -> {{dZ, dY, dX, dt}, {dZ, dY, dX, 
                  dt}}]]]},
          {"\<\"- - - - - - - -\"\>"},
          {"\<\"Current first-order structure of semimartingale \
differentials:\"\>"},
          {
            InterpretationBox[GridBox[{
                  {"dZ", "dY", "dX", "dt"},
                  {"0", "0", "0", "dt"}
                  },
                RowSpacings->3,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              
              TableForm[ {0, 0, 0, dt}, TableDirections -> Row, 
                TableHeadings -> {{dZ, dY, dX, dt}, {"Drifts:"}}]]},
          {"\<\"- - - - - - - -\"\>"},
          {"\<\"Current initial values:\"\>"},
          {
            InterpretationBox[GridBox[{
                  {"Z", "Y", "X", "t"},
                  {"Z0", "0", "1", "0"}
                  },
                RowSpacings->3,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              
              TableForm[ {Z0, 0, 1, 0}, TableDirections -> Row, 
                TableHeadings -> {{Z, Y, X, t}, {"Initially:"}}]]},
          {"\<\"---------------\"\>"}
          },
        GridBaseline->{Baseline, {1, 1}},
        ColumnAlignments->{Left}],
      ColumnForm[ {"---------------", 
        "Summary of current structure of stochastic differentials", 
        "- - - - - - - -", 
        "Current second-order structure of semimartingale differentials:", 
        TableForm[ {{
          Plus[ 
            Times[ dt, 
              Power[ X, 2]], 
            Times[ dt, 
              Power[ Y, 2]]], 
          Times[ -1, dt, X], 
          Times[ dt, Y], 0}, {
          Times[ -1, dt, X], dt, 0, 0}, {
          Times[ dt, Y], 0, dt, 0}, {0, 0, 0, 0}}, TableHeadings -> {{dZ, dY, 
          dX, dt}, {dZ, dY, dX, dt}}], "- - - - - - - -", 
        "Current first-order structure of semimartingale differentials:", 
        TableForm[ {0, 0, 0, dt}, TableDirections -> Row, TableHeadings -> {{
          dZ, dY, dX, dt}, {"Drifts:"}}], "- - - - - - - -", 
        "Current initial values:", 
        TableForm[ {Z0, 0, 1, 0}, TableDirections -> Row, TableHeadings -> {{
          Z, Y, X, t}, {"Initially:"}}], "---------------"}],
      Editable->False]], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Ito integrals"], "Section",
  Evaluatable->False],

Cell[TextData[
"Ito integrals are currently present mainly as placeholders. The simplest \
view of the Ito integral is that it is the right-inverse of the stochastic \
differential, in the sense that ItoD[ItoIntegral[sd]] == sd:"], "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[
    \(ItoD[ItoIntegral[Y\ dX]]\)], "Input",
  PageWidth->Infinity],

Cell[BoxData[
    \(dX\ Y\)], "Output"]
}, Open  ]],

Cell[TextData[
"In fact  Itovsn3  already knows the very simplest facts about Ito \
integrals:"], "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[
    \(ItoIntegral[dX]\)], "Input",
  PageWidth->Infinity],

Cell[BoxData[
    \(\(-1\) + X\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Warning", "Subsection",
  Evaluatable->False,
  FontFamily->"Times New Roman",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0],
  Background->GrayLevel[1]],

Cell["\<\
ItoIntegral[sd]  does not check to see if  sd  is of the correct form. If  sd \
 is not a stochastic differential then output will be nonsensical.\
\>", "Text",
  Evaluatable->False,
  FontColor->RGBColor[1, 0, 0]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Drift  behaves well with  ItoIntegral  (due to a careful implementation of  \
Drift!):  it leaves the argument of  ItoIntegral  untouched.\
\>", "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[
    \(ItoD[ItoIntegral[ItoD[X\^2]]\ X\^2]\)], "Input",
  PageWidth->Infinity],

Cell[BoxData[
    \(5\ dt\ X\^2 + 2\ dX\ X\^3 + dt\ ItoIntegral[dt + 2\ dX\ X] + 
      2\ dX\ X\ ItoIntegral[dt + 2\ dX\ X]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Drift[ItoD[ItoIntegral[ItoD[X\^2]]\ X\^2]]\)], "Input",
  PageWidth->Infinity],

Cell[BoxData[
    \(dt\ \((5\ X\^2 + ItoIntegral[dt + 2\ dX\ X])\)\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Programming further Ito integral properties"], "Section",
  Evaluatable->False],

Cell[TextData[
"It is possible to add on more sophisticated features, such as knowledge \
about explicit evaluations of some stochastic Ito integrals in terms of \
conventional integrals, though some care is required to ensure that the extra \
code has the desired effect! We sketch out a simple example working with  X  \
as above (assumed to be a general semimartingale) based on the Ito identity"],
   "Text",
  Evaluatable->False],

Cell[TextData[
"ItoD[X^(n+1)] ==\n (n+1) X^n ItoD[X] + ((n+1)/2) ItoExpand[ItoD[X^n] \
ItoD[X]]"], "Print",
  PageWidth->Infinity,
  Evaluatable->False,
  FontFamily->"Courier New",
  FontSize->10,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1],
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[TextData["which leads to the identity"], "Text",
  Evaluatable->False],

Cell[TextData[
"(n+1) ItoIntegral[X^n ItoD[X]] ==\n  X^(n+1)- InitialValue[0,X^(n+1)] -\n   \
((n+1)/2) ItoIntegral[ItoExpand[ItoD[X^n] ItoD[X]]]"], "Print",
  PageWidth->Infinity,
  Evaluatable->False,
  FontFamily->"Courier New",
  FontSize->10,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1],
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[TextData["and hence to the global substitutions:"], "Text",
  Evaluatable->False],

Cell[BoxData[{
    \(ItoIntegral[X_\ dX_ /; ItoD[X] == dX] := 
      1\/2\ \((X\^2 - InitialValue[0, X\^2] - 
            ItoIntegral[ItoExpand[dX\^2]])\)\), "\n", 
    \(ItoIntegral[
        X_\^n_Integer\ dX_ /; 
          ItoD[X] == 
            dX] := \(X\^\(n + 1\) - InitialValue[0, X\^\(n + 1\)] - 1\/2\ \
\((n\ \((n + 1)\))\)\ ItoIntegral[Expand[X\^\(n - 1\)\ ItoExpand[dX\^2]]]\)\/\
\(n + 1\)\)}], "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell[TextData["We can now do very simple Ito integrals:"], "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[
    \(ItoIntegral[X\ dX]\)], "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell[BoxData[
    \(1\/2\ \((\(-1\) - t + X\^2)\)\)], "Output"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ItoD[ItoIntegral[X\ dX]]\)], "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell[BoxData[
    \(dX\ X\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ItoIntegral[X\^3\ dX]\)], "Input",
  PageWidth->Infinity],

Cell[BoxData[
    \(1\/4\ \((\(-1\) + X\^4 - 6\ ItoIntegral[dt\ X\^2])\)\)], "Output"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ItoD[ItoIntegral[X\^3\ dX]]\)], "Input",
  PageWidth->Infinity],

Cell[BoxData[
    \(dX\ X\^3\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"We now call on the well-known relationship between Ito differentials and \
Hermite polynomials:"], "Text",
  Evaluatable->False,
  FontFamily->"Times New Roman",
  FontSize->12,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1],
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[{H[0, X, t], H[1, X, t], H[2, X, t], H[3, X, t], H[4, X, t], 
        H[5, X, t], H[6, X, t]}]\)], "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell[BoxData[
    \({H[0, X, t], H[1, X, t], H[2, X, t], H[3, X, t], H[4, X, t], 
      H[5, X, t], H[6, X, t]}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(H[n_, x_, t_] := 
      HermiteH[n, x\/\@\(2\ t\)]\ \((\@\(2\ t\))\)\^n\)], "Input",
  PageWidth->Infinity],

Cell[TextData[
"First note that  ItoD  sends  H[n+1,X,t]  to  2*(n+1)*H[n,X,t]: "], "Text",
  Evaluatable->False,
  FontFamily->"Times New Roman",
  FontSize->12,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1],
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[
      ItoD[H[n + 1, X, t]]\/\(2\ \((n + 1)\)\ H[n, X, t]\) /. 
        n \[Rule] {0, 1, 2, 3, 4, 5, 6}]\)], "Input",
  PageWidth->Infinity],

Cell[BoxData[
    \({dX, dX, dX, dX, dX, dX, dX}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[
"We need some linearity for the Ito integrals for the next part:  "], "Text",
  Evaluatable->False],

Cell[BoxData[{
    \(\(ItoIntegral[0] := 0;\)\), "\n", 
    \(\(ItoIntegral[sda_ + sdb_] := 
        ItoIntegral[sda] + ItoIntegral[sdb];\)\), "\n", 
    \(\(ItoIntegral[sda_ - sdb_] := 
        ItoIntegral[sda] - ItoIntegral[sdb];\)\), "\n", 
    \(\(ItoIntegral[\(-sdb_\)] := \(-ItoIntegral[sdb]\);\)\), "\n", 
    \(\(ItoIntegral[n_Integer\ sda_] := n\ ItoIntegral[sda];\)\), "\n", 
    \(\(ItoIntegral[sda_\/n_Integer] := ItoIntegral[sda]\/n;\)\)}], "Input",
  PageWidth->Infinity],

Cell[TextData[
"Now try Ito integration of stochastic differentials involving Hermite \
polynomials. "], "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n := 0;\)\), "\n", 
    \(0 == Simplify[
        ItoIntegral[
            Expand[H[n, X, 
                  t]\ dX]] - \(H[n + 1, X, t] - InitialValue[0, Simplify[H[n \
+ 1, X, t]]]\)\/\(2\ \((n + 1)\)\)]\)}], "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n := 1;\)\), "\n", 
    \(0 == Simplify[
        ItoIntegral[
            Expand[H[n, X, 
                  t]\ dX]] - \(H[n + 1, X, t] - InitialValue[0, Simplify[H[n \
+ 1, X, t]]]\)\/\(2\ \((n + 1)\)\)]\)}], "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n := 2;\)\), "\n", 
    \(0 == Simplify[
        ItoIntegral[
            Expand[H[n, X, 
                  t]\ dX]] - \(H[n + 1, X, t] - InitialValue[0, Simplify[H[n \
+ 1, X, t]]]\)\/\(2\ \((n + 1)\)\)]\)}], "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell[BoxData[
    \(0 \[Equal] 
      4\ t\ X - 4\ ItoIntegral[dX\ t] - 4\ ItoIntegral[dt\ X]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"We now see the need to deal with Ito integrals with semimartingales in the \
integrand which have no martingale part: this is more like ordinary \
integration by parts! To avoid complications, we deal only with the time-like \
semimartingale  t  and the general semimartingale  X  (here a standard \
Brownian motion). \n\nEXERCISE: do better than this!. "], "Text",
  Evaluatable->False,
  FontFamily->"Times New Roman",
  FontSize->12,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1],
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Clear[n];\)\), "\n", 
    \(\(SetAttributes[m, Constant];\)\), "\n", 
    \(\(SetAttributes[n, Constant];\)\), "\n", 
    \(ItoD[t\^m\ X\^n]\)}], "Input",
  PageWidth->Infinity],

Cell[BoxData[
    \(\(-\(1\/2\)\)\ dt\ n\ t\^m\ X\^\(\(-2\) + n\) + 
      1\/2\ dt\ n\^2\ t\^m\ X\^\(\(-2\) + n\) + 
      dX\ n\ t\^m\ X\^\(\(-1\) + n\) + 
      dt\ m\ t\^\(\(-1\) + m\)\ X\^n\)], "Output"]
}, Open  ]],

Cell[TextData["which leads to the identity"], "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[
      ItoD[t\^m\ X\^\(n + 1\)] == 
        m\ t\^\(m - 1\)\ X\^\(n + 1\)\ dt + \((n + 1)\)\ t\^m\ X\^n\ dX + 
          1\/2\ \((n + 1)\)\ n\ t\^m\ X\^\(n - 1\)\ dt]\)], "Input",
  PageWidth->Infinity],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[TextData[
"From this calculation we derive the following rules. Notice here that no \
check is made on the signs of the integers  n  and  m,  which should both be \
non-negative!"], "Text",
  Evaluatable->False],

Cell[BoxData[{
    \(ItoIntegral[t\ dX] := 
      t\ X - InitialValue[0, t\ X] - 
        ItoIntegral[Expand[X\ ItoD[t]]]\), "\n", 
    \(ItoIntegral[t\ X\ dX] := 
      1\/2\ \((t\ X\^2 - InitialValue[0, t\ X\^2] - ItoIntegral[X\^2\ dt] - 
            ItoIntegral[t\ dt])\)\), "\n", 
    \(ItoIntegral[t\^m_Integer\ dX] := 
      t\^m\ X - InitialValue[0, t\^m\ X] - 
        ItoIntegral[Expand[X\ ItoD[t\^m]]]\), "\n", 
    \(ItoIntegral[t\^m_Integer\ X\ dX] := 
      1\/2\ \((t\^m\ X\^2 - InitialValue[0, t\^m\ X\^2] - 
            ItoIntegral[m\ t\^\(m - 1\)\ X\^2\ dt] - 
            ItoIntegral[t\^m\ dt])\)\), "\n", 
    \(ItoIntegral[
        t\ X\^n_Integer\ dX] := \(t\ X\^\(n + 1\) - InitialValue[0, t\ X\^\(n \
+ 1\)] - ItoIntegral[X\^\(n + 1\)\ dt] - ItoIntegral[1\/2\ \((n + 1)\)\ n\ t\ \
X\^\(n - 1\)\ dt]\)\/\(n + 1\)\), "\n", 
    \(ItoIntegral[
        t\^m_Integer\ X\^n_Integer\ dX] := \(t\^m\ X\^\(n + 1\) - \
InitialValue[0, t\^m\ X\^\(n + 1\)] - ItoIntegral[m\ t\^\(m - 1\)\ X\^\(n + 1\
\)\ dt] - ItoIntegral[1\/2\ \((n + 1)\)\ n\ t\^m\ X\^\(n - 1\)\ dt]\)\/\(n + \
1\)\)}], "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]]
}, Open  ]],

Cell[TextData[
"The next sub-section is a long check on a sequence of Hermite polynomials."],
   "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[TextData[
"Checking the Ito integral of Hermite polynomials from orders  1  to  10"], 
  "Subsection",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n := 0;\)\), "\n", 
    \(0 == Simplify[
        ItoIntegral[
            Expand[H[n, X, 
                  t]\ dX]] - \(H[n + 1, X, t] - InitialValue[0, Simplify[H[n \
+ 1, X, t]]]\)\/\(2\ \((n + 1)\)\)]\)}], "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n := 1;\)\), "\n", 
    \(0 == Simplify[
        ItoIntegral[
            Expand[H[n, X, 
                  t]\ dX]] - \(H[n + 1, X, t] - InitialValue[0, Simplify[H[n \
+ 1, X, t]]]\)\/\(2\ \((n + 1)\)\)]\)}], "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n := 2;\)\), "\n", 
    \(0 == Simplify[
        ItoIntegral[
            Expand[H[n, X, 
                  t]\ dX]] - \(H[n + 1, X, t] - InitialValue[0, Simplify[H[n \
+ 1, X, t]]]\)\/\(2\ \((n + 1)\)\)]\)}], "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n := 3;\)\), "\n", 
    \(0 == Simplify[
        ItoIntegral[
            Expand[H[n, X, 
                  t]\ dX]] - \(H[n + 1, X, t] - InitialValue[0, Simplify[H[n \
+ 1, X, t]]]\)\/\(2\ \((n + 1)\)\)]\)}], "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n := 4;\)\), "\n", 
    \(0 == Simplify[
        ItoIntegral[
            Expand[H[n, X, 
                  t]\ dX]] - \(H[n + 1, X, t] - InitialValue[0, Simplify[H[n \
+ 1, X, t]]]\)\/\(2\ \((n + 1)\)\)]\)}], "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n := 5;\)\), "\n", 
    \(0 == Simplify[
        ItoIntegral[
            Expand[H[n, X, 
                  t]\ dX]] - \(H[n + 1, X, t] - InitialValue[0, Simplify[H[n \
+ 1, X, t]]]\)\/\(2\ \((n + 1)\)\)]\)}], "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n := 6;\)\), "\n", 
    \(0 == Simplify[
        ItoIntegral[
            Expand[H[n, X, 
                  t]\ dX]] - \(H[n + 1, X, t] - InitialValue[0, Simplify[H[n \
+ 1, X, t]]]\)\/\(2\ \((n + 1)\)\)]\)}], "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n := 7;\)\), "\n", 
    \(0 == Simplify[
        ItoIntegral[
            Expand[H[n, X, 
                  t]\ dX]] - \(H[n + 1, X, t] - InitialValue[0, Simplify[H[n \
+ 1, X, t]]]\)\/\(2\ \((n + 1)\)\)]\)}], "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n := 9;\)\), "\n", 
    \(0 == Simplify[
        ItoIntegral[
            Expand[H[n, X, 
                  t]\ dX]] - \(H[n + 1, X, t] - InitialValue[0, Simplify[H[n \
+ 1, X, t]]]\)\/\(2\ \((n + 1)\)\)]\)}], "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n := 10;\)\), "\n", 
    \(0 == Simplify[
        ItoIntegral[
            Expand[H[n, X, 
                  t]\ dX]] - \(H[n + 1, X, t] - InitialValue[0, Simplify[H[n \
+ 1, X, t]]]\)\/\(2\ \((n + 1)\)\)]\)}], "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Finally, a couple of random checks:"], "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[
    \(ItoIntegral[t\^5\ dX]\)], "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell[BoxData[
    \(t\^5\ X - 5\ ItoIntegral[dt\ t\^4\ X]\)], "Output"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ItoD[ItoIntegral[t\^5\ dX]]\)], "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell[BoxData[
    \(dX\ t\^5\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ItoIntegral[t\^5\ X\^2\ dX]\)], "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell[BoxData[
    \(1\/3\ \((t\^5\ X\^3 - 3\ ItoIntegral[dt\ t\^5\ X] - 
          5\ ItoIntegral[dt\ t\^4\ X\^3])\)\)], "Output"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ItoD[ItoIntegral[t\^5\ X\^2\ dX]]\)], "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell[BoxData[
    \(dX\ t\^5\ X\^2\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{1016, 651},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
StyleDefinitions -> "PastelColor.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 106, 3, 147, "Title",
  Evaluatable->False],
Cell[1863, 56, 119, 3, 62, "Subtitle",
  Evaluatable->False],
Cell[1985, 61, 173, 4, 58, "Subsubtitle",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[2183, 69, 347, 12, 35, "SmallText",
  Evaluatable->False],
Cell[2533, 83, 265, 8, 31, "Name",
  Evaluatable->False],
Cell[2801, 93, 240, 7, 31, "Name",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[3078, 105, 354, 12, 35, "SmallText",
  Evaluatable->False],
Cell[3435, 119, 953, 21, 88, "SmallText",
  Evaluatable->False]
}, Closed]],
Cell[4403, 143, 794, 16, 148, "SmallText",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[5222, 163, 317, 11, 35, "SmallText",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[5564, 178, 449, 14, 40, "SmallText",
  Evaluatable->False],
Cell[6016, 194, 279, 8, 44, "SmallText",
  Evaluatable->False],
Cell[6298, 204, 338, 9, 44, "SmallText",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[6673, 218, 338, 11, 40, "SmallText",
  Evaluatable->False],
Cell[7014, 231, 333, 9, 44, "SmallText",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[7384, 245, 343, 11, 40, "SmallText",
  Evaluatable->False],
Cell[7730, 258, 357, 9, 44, "SmallText",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[8124, 272, 337, 11, 40, "SmallText",
  Evaluatable->False],
Cell[8464, 285, 337, 9, 44, "SmallText",
  Evaluatable->False]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[8850, 300, 434, 7, 160, "Text",
  Evaluatable->False],
Cell[9287, 309, 204, 7, 38, "Input"]
}, Closed]],
Cell[9506, 319, 54, 1, 71, "Input"],

Cell[CellGroupData[{
Cell[9585, 324, 59, 1, 74, "Section",
  Evaluatable->False],
Cell[9647, 327, 601, 9, 162, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[10273, 340, 193, 7, 49, "Input"],
Cell[10469, 349, 871, 23, 137, "Output"]
}, Open  ]],
Cell[11355, 375, 628, 16, 102, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[12008, 395, 67, 2, 73, "Input"],
Cell[12078, 399, 2445, 60, 324, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[14572, 465, 77, 1, 74, "Section",
  Evaluatable->False],
Cell[14652, 468, 125, 3, 42, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[14802, 475, 72, 2, 73, "Input"],
Cell[14877, 479, 42, 1, 72, "Output"]
}, Open  ]],
Cell[14934, 483, 215, 4, 72, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[15174, 491, 67, 2, 73, "Input"],
Cell[15244, 495, 2886, 72, 421, "Print"]
}, Open  ]],
Cell[18145, 570, 98, 1, 42, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[18268, 575, 63, 2, 73, "Input"],
Cell[18334, 579, 36, 1, 72, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18407, 585, 71, 2, 74, "Input"],
Cell[18481, 589, 65, 1, 72, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18583, 595, 174, 6, 55, "Subsection",
  Evaluatable->False],
Cell[18760, 603, 233, 6, 29, "Text",
  Evaluatable->False]
}, Closed]],
Cell[19008, 612, 81, 1, 40, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[19114, 617, 71, 2, 73, "Input"],
Cell[19188, 621, 79, 1, 72, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19304, 627, 182, 6, 55, "Subsection",
  Evaluatable->False],
Cell[19489, 635, 214, 5, 33, "Text",
  Evaluatable->False]
}, Closed]],
Cell[19718, 643, 95, 1, 40, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[19838, 648, 79, 2, 73, "Input"],
Cell[19920, 652, 45, 1, 72, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[20014, 659, 116, 3, 74, "Section",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[20155, 666, 150, 3, 72, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[20330, 673, 77, 2, 74, "Input"],
Cell[20410, 677, 35, 1, 72, "Output"]
}, Open  ]],
Cell[20460, 681, 363, 12, 42, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[20848, 697, 58, 2, 73, "Input"],
Cell[20909, 701, 47, 1, 72, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20993, 707, 59, 2, 73, "Input"],
Cell[21055, 711, 61, 1, 72, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[21153, 717, 83, 2, 55, "Subsection",
  Evaluatable->False],
Cell[21239, 721, 764, 12, 109, "Text",
  Evaluatable->False]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[22052, 739, 64, 1, 42, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[22141, 744, 71, 2, 73, "Input"],
Cell[22215, 748, 35, 1, 72, "Output"]
}, Open  ]],
Cell[22265, 752, 99, 1, 42, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[22389, 757, 59, 2, 73, "Input"],
Cell[22451, 761, 36, 1, 72, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22524, 767, 83, 2, 55, "Subsection",
  Evaluatable->False],
Cell[22610, 771, 435, 8, 71, "Text",
  Evaluatable->False]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[23094, 785, 516, 14, 72, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[23635, 803, 61, 2, 74, "Input"],
Cell[23699, 807, 39, 1, 74, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23775, 813, 72, 2, 74, "Input"],
Cell[23850, 817, 36, 1, 72, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[23935, 824, 176, 3, 42, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[24136, 831, 73, 2, 73, "Input"],
Cell[24212, 835, 35, 1, 72, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[24284, 841, 80, 2, 74, "Input"],
Cell[24367, 845, 35, 1, 72, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[24439, 851, 182, 6, 55, "Subsection",
  Evaluatable->False],
Cell[24624, 859, 147, 4, 33, "Text",
  Evaluatable->False]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[24820, 869, 126, 3, 42, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[24971, 876, 67, 2, 73, "Input"],
Cell[25041, 880, 2647, 65, 420, "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[27749, 952, 130, 3, 74, "Section",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[27904, 959, 86, 1, 42, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[28015, 964, 72, 2, 73, "Input"],
Cell[28090, 968, 46, 1, 72, "Output"]
}, Open  ]],
Cell[28151, 972, 100, 1, 42, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[28276, 977, 145, 4, 126, "Input"],
Cell[28424, 983, 35, 1, 72, "Output"],
Cell[28462, 986, 35, 1, 72, "Output"],
Cell[28500, 989, 35, 1, 72, "Output"]
}, Open  ]]
}, Open  ]],
Cell[28562, 994, 404, 13, 42, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[28991, 1011, 189, 7, 49, "Input"],
Cell[29183, 1020, 2962, 72, 442, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[32182, 1097, 91, 1, 42, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[32298, 1102, 212, 4, 125, "Input"],
Cell[32513, 1108, 35, 1, 72, "Output"],
Cell[32551, 1111, 35, 1, 72, "Output"],
Cell[32589, 1114, 35, 1, 72, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[32673, 1121, 83, 2, 55, "Subsection",
  Evaluatable->False],
Cell[32759, 1125, 533, 10, 71, "Text",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[33329, 1140, 189, 7, 47, "Input"],
Cell[33521, 1149, 2816, 68, 442, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[36374, 1222, 121, 3, 42, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[36520, 1229, 74, 2, 95, "Input"],
Cell[36597, 1233, 110, 2, 91, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[36744, 1240, 182, 6, 55, "Subsection",
  Evaluatable->False],
Cell[36929, 1248, 442, 8, 71, "Text",
  Evaluatable->False]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[37432, 1263, 112, 2, 74, "Section",
  Evaluatable->False],
Cell[37547, 1267, 136, 3, 42, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[37708, 1274, 71, 2, 73, "Input"],
Cell[37782, 1278, 871, 23, 137, "Output"]
}, Open  ]],
Cell[38668, 1304, 441, 13, 72, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[39134, 1321, 239, 8, 75, "Input"],
Cell[39376, 1331, 2816, 68, 442, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[42241, 1405, 98, 1, 74, "Section",
  Evaluatable->False],
Cell[42342, 1408, 296, 5, 72, "Text",
  Evaluatable->False],
Cell[42641, 1415, 90, 2, 73, "Input"],
Cell[42734, 1419, 74, 1, 42, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[42833, 1424, 67, 2, 73, "Input"],
Cell[42903, 1428, 3270, 79, 469, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[46222, 1513, 64, 1, 74, "Section",
  Evaluatable->False],
Cell[46289, 1516, 261, 4, 72, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[46575, 1524, 80, 2, 73, "Input"],
Cell[46658, 1528, 39, 1, 72, "Output"]
}, Open  ]],
Cell[46712, 1532, 127, 3, 42, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[46864, 1539, 71, 2, 73, "Input"],
Cell[46938, 1543, 44, 1, 72, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[47019, 1549, 182, 6, 55, "Subsection",
  Evaluatable->False],
Cell[47204, 1557, 224, 5, 33, "Text",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[47465, 1567, 184, 4, 70, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[47674, 1575, 91, 2, 74, "Input"],
Cell[47768, 1579, 138, 2, 74, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[47943, 1586, 98, 2, 74, "Input"],
Cell[48044, 1590, 80, 1, 74, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[48185, 1598, 94, 1, 74, "Section",
  Evaluatable->False],
Cell[48282, 1601, 434, 7, 132, "Text",
  Evaluatable->False],
Cell[48719, 1610, 401, 14, 47, "Print",
  Evaluatable->False],
Cell[49123, 1626, 75, 1, 42, "Text",
  Evaluatable->False],
Cell[49201, 1629, 451, 14, 66, "Print",
  Evaluatable->False],
Cell[49655, 1645, 86, 1, 42, "Text",
  Evaluatable->False],
Cell[49744, 1648, 560, 15, 141, "Input"],
Cell[50307, 1665, 88, 1, 42, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[50420, 1670, 196, 7, 49, "Input"],
Cell[50619, 1679, 63, 1, 88, "Output"],

Cell[CellGroupData[{
Cell[50707, 1684, 202, 7, 49, "Input"],
Cell[50912, 1693, 39, 1, 72, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[51000, 1700, 77, 2, 74, "Input"],
Cell[51080, 1704, 86, 1, 88, "Output"],

Cell[CellGroupData[{
Cell[51191, 1709, 83, 2, 74, "Input"],
Cell[51277, 1713, 42, 1, 74, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[51368, 1720, 397, 13, 42, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[51790, 1737, 281, 8, 49, "Input"],
Cell[52074, 1747, 125, 2, 72, "Output"]
}, Open  ]],
Cell[52214, 1752, 127, 3, 101, "Input"],
Cell[52344, 1757, 366, 12, 42, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[52735, 1773, 169, 4, 99, "Input"],
Cell[52907, 1779, 62, 1, 72, "Output"]
}, Open  ]]
}, Open  ]],
Cell[52996, 1784, 114, 2, 42, "Text",
  Evaluatable->False],
Cell[53113, 1788, 485, 9, 235, "Input"],
Cell[53601, 1799, 134, 3, 42, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[53760, 1806, 386, 12, 104, "Input"],
Cell[54149, 1820, 38, 1, 72, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[54224, 1826, 386, 12, 104, "Input"],
Cell[54613, 1840, 38, 1, 72, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[54688, 1846, 386, 12, 104, "Input"],
Cell[55077, 1860, 107, 2, 72, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[55221, 1867, 656, 16, 162, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[55902, 1887, 200, 5, 151, "Input"],
Cell[56105, 1894, 208, 4, 88, "Output"]
}, Open  ]],
Cell[56328, 1901, 75, 1, 42, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[56428, 1906, 231, 5, 96, "Input"],
Cell[56662, 1913, 38, 1, 72, "Output"]
}, Open  ]],
Cell[56715, 1917, 216, 4, 72, "Text",
  Evaluatable->False],
Cell[56934, 1923, 1252, 28, 322, "Input"]
}, Open  ]],
Cell[58201, 1954, 126, 3, 42, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[58352, 1961, 129, 3, 55, "Subsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[58506, 1968, 386, 12, 104, "Input"],
Cell[58895, 1982, 38, 1, 72, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[58970, 1988, 386, 12, 104, "Input"],
Cell[59359, 2002, 38, 1, 72, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[59434, 2008, 386, 12, 104, "Input"],
Cell[59823, 2022, 38, 1, 72, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[59898, 2028, 386, 12, 104, "Input"],
Cell[60287, 2042, 38, 1, 72, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[60362, 2048, 386, 12, 104, "Input"],
Cell[60751, 2062, 38, 1, 72, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[60826, 2068, 386, 12, 104, "Input"],
Cell[61215, 2082, 38, 1, 72, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[61290, 2088, 386, 12, 104, "Input"],
Cell[61679, 2102, 38, 1, 72, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[61754, 2108, 386, 12, 104, "Input"],
Cell[62143, 2122, 38, 1, 72, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[62218, 2128, 386, 12, 104, "Input"],
Cell[62607, 2142, 38, 1, 72, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[62682, 2148, 387, 12, 104, "Input"],
Cell[63072, 2162, 38, 1, 72, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[63159, 2169, 83, 1, 42, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[63267, 2174, 199, 7, 50, "Input"],
Cell[63469, 2183, 71, 1, 74, "Output"],

Cell[CellGroupData[{
Cell[63565, 2188, 205, 7, 50, "Input"],
Cell[63773, 2197, 42, 1, 74, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[63864, 2204, 205, 7, 50, "Input"],
Cell[64072, 2213, 130, 2, 88, "Output"],

Cell[CellGroupData[{
Cell[64227, 2219, 211, 7, 50, "Input"],
Cell[64441, 2228, 48, 1, 74, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

