(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     10844,        367]*)
(*NotebookOutlinePosition[     11526,        390]*)
(*  CellTagsIndexPosition[     11482,        386]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Itoexp", "Title",
  TextAlignment->Center],

Cell["Wilfrid S.Kendall ", "Subtitle",
  TextAlignment->Center],

Cell["Statistics,University of Warwick Coventry CV4 7AL,UK.", "Subsubtitle",
  TextAlignment->Center],

Cell["Contact information:", "SmallText",
  Editable->False,
  Evaluatable->False,
  FontFamily->"Times New Roman",
  FontSize->10,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontColor->RGBColor[0.501961, 0, 0],
  Background->GrayLevel[1],
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell["Email: w.s.kendall@warwick.ac.uk", "Name",
  Editable->False,
  Evaluatable->False,
  CellHorizontalScrolling->False,
  FontFamily->"Times New Roman",
  FontSize->10,
  FontSlant->"Italic",
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell["URL: http://www.warwick.ac.uk/go/WSK", "Name",
  Editable->False,
  Evaluatable->False,
  CellHorizontalScrolling->False,
  FontFamily->"Times New Roman",
  FontSize->10,
  FontSlant->"Italic",
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell["Version 0.2 Copyright 1992, 2005. ", "Text"],

Cell["Mathematica script to introduce Ito calculus.", "Text"],

Cell[BoxData[
    \(Needs["\<Itovsn3`\>"]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Print[ItoInit[t, dt]]\)], "Input"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {"\<\"Itovsn3  initialized\"\>"},
          {
            
            InterpretationBox[\("with time semimartingale "\[InvisibleSpace]t\
\),
              SequenceForm[ "with time semimartingale ", t],
              Editable->False]},
          {
            
            InterpretationBox[\("and time differential "\[InvisibleSpace]dt\),
              
              SequenceForm[ "and time differential ", dt],
              Editable->False]}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {"Itovsn3  initialized", 
        SequenceForm[ "with time semimartingale ", t], 
        SequenceForm[ "and time differential ", dt]}]]], "Print"]
}, Open  ]],

Cell["\<\
Introducing a Brownian motion (of course we could use BrownSingle...)\
\>", "Text"],

Cell[BoxData[{
    \(\(Introduce[X, dX];\)\), "\n", 
    \(AddFixed[X, X0]; AddDrift[dX, 0]; AddQuadVar[dX^2, dt];\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Print["\<Some simple stochastic calculus:\>"];\)\), "\n", 
    \(\(ItoStatus[];\)\)}], "Input"],

Cell[BoxData[
    \("Some simple stochastic calculus:"\)], "Print"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {"\<\"---------------\"\>"},
          {"\<\"Summary of current structure of stochastic \
differentials\"\>"},
          {"\<\"- - - - - - - -\"\>"},
          {"\<\"Current second-order structure of semimartingale \
differentials:\"\>"},
          {
            TagBox[GridBox[{
                  {"\<\"\"\>", "dX", "dt"},
                  {"dX", "dt", "0"},
                  {"dt", "0", "0"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              Function[ BoxForm`e$, 
                TableForm[ 
                BoxForm`e$, TableHeadings -> {{dX, dt}, {dX, dt}}]]]},
          {"\<\"- - - - - - - -\"\>"},
          {"\<\"Current first-order structure of semimartingale \
differentials:\"\>"},
          {
            InterpretationBox[GridBox[{
                  {"dX", "dt"},
                  {"0", "dt"}
                  },
                RowSpacings->3,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              
              TableForm[ {0, dt}, TableDirections -> Row, TableHeadings -> {{
                dX, dt}, {"Drifts:"}}]]},
          {"\<\"- - - - - - - -\"\>"},
          {"\<\"Current initial values:\"\>"},
          {
            InterpretationBox[GridBox[{
                  {"X", "t"},
                  {\(Fixed[0, X]\), "0"}
                  },
                RowSpacings->3,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              TableForm[ {
                Fixed[ 0, X], 0}, TableDirections -> Row, TableHeadings -> {{
                X, t}, {"Initially:"}}]]},
          {"\<\"---------------\"\>"}
          },
        GridBaseline->{Baseline, {1, 1}},
        ColumnAlignments->{Left}],
      ColumnForm[ {"---------------", 
        "Summary of current structure of stochastic differentials", 
        "- - - - - - - -", 
        "Current second-order structure of semimartingale differentials:", 
        TableForm[ {{dt, 0}, {0, 0}}, TableHeadings -> {{dX, dt}, {dX, dt}}], 
        "- - - - - - - -", 
        "Current first-order structure of semimartingale differentials:", 
        TableForm[ {0, dt}, TableDirections -> Row, TableHeadings -> {{dX, 
          dt}, {"Drifts:"}}], "- - - - - - - -", "Current initial values:", 
        TableForm[ {
          Fixed[ 0, X], 0}, TableDirections -> Row, TableHeadings -> {{X, 
          t}, {"Initially:"}}], "---------------"}],
      Editable->False]], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Print["\<Ito differential of \>"];\)\), "\n", 
    \(\(Print[X^2];\)\), "\n", 
    \(\(Print["\< is \>"];\)\), "\n", 
    \(\(Print[ItoD[X^2]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Drift of above is\>"];\)\), "\n", 
    \(\(Print[Drift[ItoD[X^2]]];\)\)}], "Input"],

Cell[BoxData[
    \("Ito differential of "\)], "Print"],

Cell[BoxData[
    \(X\^2\)], "Print"],

Cell[BoxData[
    \(" is "\)], "Print"],

Cell[BoxData[
    \(dt + 2\ dX\ X\)], "Print"],

Cell[BoxData[
    \("Drift of above is"\)], "Print"],

Cell[BoxData[
    \(dt\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(SetAttributes[u, Constant];\)\), "\n", 
    \(Z = Exp[u\ X - u^2\ t/2]\), "\n", 
    \(\(Print["\<Ito differential of  Z =\>"];\)\), "\n", 
    \(\(Print[Exp[u\ X - u^2\ t/2]];\)\), "\n", 
    \(\(Print["\< (for  u  constant) is \>"];\)\), "\n", 
    \(\(Print[ItoD[Z]];\)\), "\n", 
    \(\(Print["\<\>"];\)\), "\n", 
    \(\(Print["\<Drift of above is\>"];\)\), "\n", 
    \(\(Print[Drift[ItoD[Z]]];\)\)}], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(\(-\(\(t\ u\^2\)\/2\)\) + u\ X\)\)], "Output"],

Cell[BoxData[
    \("Ito differential of  Z ="\)], "Print"],

Cell[BoxData[
    \(\[ExponentialE]\^\(\(-\(\(t\ u\^2\)\/2\)\) + u\ X\)\)], "Print"],

Cell[BoxData[
    \(" (for  u  constant) is "\)], "Print"],

Cell[BoxData[
    \(dX\ \[ExponentialE]\^\(\(-\(\(t\ u\^2\)\/2\)\) + u\ X\)\ u\)], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    \("Drift of above is"\)], "Print"],

Cell[BoxData[
    \(0\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Y = Exp[ItoIntegral[v\ dX] - ItoIntegral[v^2\ dt]/2]\), "\n", 
    \(\(Print["\<Ito differential of  Y = \>"];\)\), "\n", 
    \(\(Print[Y];\)\), "\n", 
    \(\(Print["\< (for  v  nonconstant) is \>"];\)\), "\n", 
    \(\(Print[ItoD[Y]];\)\), "\n", 
    \(\(Print["\<\>"];\)\), "\n", 
    \(\(Print["\<Drift of above is\>"];\)\), "\n", 
    \(\(Print[Drift[ItoD[Y]]];\)\)}], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(ItoIntegral[dX\ v] - 1\/2\ ItoIntegral[dt\ \
v\^2]\)\)], "Output"],

Cell[BoxData[
    \("Ito differential of  Y = "\)], "Print"],

Cell[BoxData[
    \(\[ExponentialE]\^\(ItoIntegral[dX\ v] - 1\/2\ ItoIntegral[dt\ \
v\^2]\)\)], "Print"],

Cell[BoxData[
    \(" (for  v  nonconstant) is "\)], "Print"],

Cell[BoxData[
    \(dX\ \[ExponentialE]\^\(ItoIntegral[dX\ v] - 1\/2\ ItoIntegral[dt\ v\^2]\
\)\ v\)], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    \("Drift of above is"\)], "Print"],

Cell[BoxData[
    \(0\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Print["\<Now try a local martingale \n
made out of the heat kernel ... \>"];\)\), "\n", 
    \(\(p = 
        Exp[\(-X^2\)/\((2\ \((1 - t)\))\)]/
          Sqrt[2\ Pi\ \((1 - t)\)];\)\), "\n", 
    \(\(Print["\<Ito differential of  p = \>"];\)\), "\n", 
    \(\(Print[p];\)\), "\n", 
    \(\(Print[ItoD[p]];\)\), "\n", 
    \(\(Print["\<\>"];\)\), "\n", 
    \(\(Print["\<Drift of above is\>"];\)\), "\n", 
    \(\(Print[Drift[ItoD[p]]];\)\)}], "Input"],

Cell[BoxData[
    \("Now try a local martingale \n made out of the heat kernel ... "\)], \
"Print"],

Cell[BoxData[
    \("Ito differential of  p = "\)], "Print"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-\(X\^2\/\(2\ \((1 - t)\)\)\)\)\/\(\@\(2\ \[Pi]\)\ \
\@\(1 - t\)\)\)], "Print"],

Cell[BoxData[
    \(\(-\(\(dX\ \[ExponentialE]\^\(-\(X\^2\/\(2\ \((1 - t)\)\)\)\)\ \
X\)\/\(\@\(2\ \[Pi]\)\ \((1 - t)\)\^\(3/2\)\)\)\)\)], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    \("Drift of above is"\)], "Print"],

Cell[BoxData[
    \(0\)], "Print"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowSize->{1016, 651},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
StyleDefinitions -> "PastelColor.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 48, 1, 147, "Title"],
Cell[1827, 56, 63, 1, 62, "Subtitle"],
Cell[1893, 59, 101, 1, 32, "Subsubtitle"],
Cell[1997, 62, 347, 12, 35, "SmallText",
  Evaluatable->False],
Cell[2347, 76, 255, 8, 31, "Name",
  Evaluatable->False],
Cell[2605, 86, 259, 8, 31, "Name",
  Evaluatable->False],
Cell[2867, 96, 50, 0, 42, "Text"],
Cell[2920, 98, 61, 0, 42, "Text"],
Cell[2984, 100, 54, 1, 73, "Input"],

Cell[CellGroupData[{
Cell[3063, 105, 54, 1, 73, "Input"],
Cell[3120, 108, 798, 22, 97, "Print"]
}, Open  ]],
Cell[3933, 133, 93, 2, 42, "Text"],
Cell[4029, 137, 128, 2, 125, "Input"],

Cell[CellGroupData[{
Cell[4182, 143, 118, 2, 99, "Input"],
Cell[4303, 147, 67, 1, 56, "Print"],
Cell[4373, 150, 2694, 66, 421, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7104, 221, 296, 6, 203, "Input"],
Cell[7403, 229, 55, 1, 56, "Print"],
Cell[7461, 232, 37, 1, 58, "Print"],
Cell[7501, 235, 39, 1, 56, "Print"],
Cell[7543, 238, 46, 1, 56, "Print"],
Cell[7592, 241, 52, 1, 56, "Print"],
Cell[7647, 244, 35, 1, 56, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7719, 250, 439, 9, 281, "Input"],
Cell[8161, 261, 85, 1, 87, "Output"],
Cell[8249, 264, 59, 1, 56, "Print"],
Cell[8311, 267, 84, 1, 71, "Print"],
Cell[8398, 270, 58, 1, 56, "Print"],
Cell[8459, 273, 91, 1, 71, "Print"],
Cell[8553, 276, 45, 1, 56, "Print"],
Cell[8601, 279, 52, 1, 56, "Print"],
Cell[8656, 282, 34, 1, 56, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8727, 288, 404, 8, 255, "Input"],
Cell[9134, 298, 105, 2, 82, "Output"],
Cell[9242, 302, 60, 1, 56, "Print"],
Cell[9305, 305, 104, 2, 66, "Print"],
Cell[9412, 309, 61, 1, 56, "Print"],
Cell[9476, 312, 111, 2, 66, "Print"],
Cell[9590, 316, 45, 1, 56, "Print"],
Cell[9638, 319, 52, 1, 56, "Print"],
Cell[9693, 322, 34, 1, 56, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9764, 328, 476, 11, 281, "Input"],
Cell[10243, 341, 99, 2, 81, "Print"],
Cell[10345, 345, 60, 1, 56, "Print"],
Cell[10408, 348, 118, 2, 100, "Print"],
Cell[10529, 352, 147, 2, 100, "Print"],
Cell[10679, 356, 45, 1, 56, "Print"],
Cell[10727, 359, 52, 1, 56, "Print"],
Cell[10782, 362, 34, 1, 56, "Print"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

